{% from 'events/_get_history_list.sql' import get_history_list %}
WITH history_list(node) AS (
    {{ get_history_list(
        code_pk,
        mp
    ) }}
    {# the parameters of code_pk and material path will be used to get the history list #}
)
SELECT
    COALESCE(
        (
            {# in case the historical event contains a date key #}
            SELECT
                history_node.value ->> '$.date'
        ),
        (
            {# in case the historical event is a statute, get its date #}
            SELECT
                DATE
            FROM
                statutes s
                JOIN statutetitles st
                ON st.statute_id = s.pk
            WHERE
                st.category = 'serial'
                AND LOWER(
                    st.text
                ) = LOWER(
                    history_node.value ->> '$.statute'
                )
        ),
        (
            {# in case the historical event is a decision, get its date #}
            SELECT
                d.date_prom
            FROM
                citations cite_z
                JOIN decisions d
                ON cite_z.decision_id = d.pk
            WHERE
                LOWER(
                    history_node.value ->> '$.citation'
                ) IN (LOWER(cite_z.scra), LOWER(cite_z.phil), LOWER(cite_z.offg), LOWER(cite_z.docket))
        )
    ) event_date,
    {#- when event occured -#}
    history_node.value ->> '$.action' action,
    iif(
        history_node.value ->> '$.citation',
        {#- if a citation exists, patch the original node with a decision_id -#}
        json_patch(
            history_node.value,
            json_object(
                'decision_id',
                (
                    SELECT
                        cite_x.decision_id
                    FROM
                        citations cite_x
                    WHERE
                        LOWER(
                            history_node.value ->> '$.citation'
                        ) IN (LOWER(cite_x.scra), LOWER(cite_x.phil), LOWER(cite_x.offg), LOWER(cite_x.docket))
                )
            )
        ),
        history_node.value
    ) basis
FROM
    history_list,
    json_each(node) history_node
ORDER BY
    event_date
