WITH highlights(
  id,
  text
) AS (
  SELECT
    ROWID,
    snippet(
      statutetitles_fts,
      0,
      '<mark>',
      '</mark>',
      '...',
      16
    ) highlighted
  FROM
    statutetitles_fts
  WHERE
    statutetitles_fts match :search
),
{# for each matching statute, get title details #}
statutory_titles(titles) AS (
  SELECT
    json_group_object(
      category,
      text
    )
  FROM
    statutetitles
  WHERE
    statute_id = st.statute_id
    AND category != 'alias'
),
{# for each matching statute, get codification details #}
codifications_id_list(code_id) AS (
  SELECT
    group_concat(
      pk,
      "^^^"
    )
  FROM
    codifications C
  WHERE
    C.statute_id = st.statute_id
)
/*
 The main fts search will be used both as where filter and the merging of original marked highlights;
 The other CTES help contextualize
 */
SELECT
  st.statute_id statute_id,
  (
    SELECT
      titles ->> '$.short'
    FROM
      statutory_titles
  ) short_title,
  (
    SELECT
      titles ->> '$.serial'
    FROM
      statutory_titles
  ) st_serial,
  (
    SELECT
      DATE
    FROM
      statutes
    WHERE
      pk = st.statute_id
  ) doc_date,
  COUNT(
    st.statute_id
  ) num_titles,
  group_concat(
    (
      SELECT
        text
      FROM
        highlights
      WHERE
        id = st.rowid
    ),
    '; '
  ) merged_statute_titles,
  (
    SELECT
      code_id
    FROM
      codifications_id_list
  ) csv_code_pks
FROM
  statutetitles st
WHERE
  st.rowid IN (
    SELECT
      id
    FROM
      highlights
  )
GROUP BY
  st.statute_id
ORDER BY
  num_titles DESC,
  doc_date DESC
